@@ -2,6 +2,7 @@ package Perl::PrereqScanner::NotQuiteLite::Parser::TestMore;
 
 use strict;
 use warnings;
+use Perl::PrereqScanner::NotQuiteLite::Util;
 
 sub register { return {
   use => {
@@ -10,20 +11,41 @@ sub register { return {
 }}
 
 sub parse_test_more_args {
-  my ($class, $c, $used_module, $tokens) = @_;
+  my ($class, $c, $used_module, $raw_tokens) = @_;
 
-  $c->register_keyword(
+  $c->register_keyword_parser(
     'done_testing',
     [$class, 'parse_done_testing_args', $used_module],
   );
+
+  $c->register_keyword_parser(
+    'plan',
+    [$class, 'parse_plan_args', $used_module],
+  );
 }
 
 sub parse_done_testing_args {
-  my ($class, $c, $used_module, $tokens) = @_;
+  my ($class, $c, $used_module, $raw_tokens) = @_;
 
   $c->add($used_module => '0.88');
 }
 
+sub parse_plan_args {
+  my ($class, $c, $used_module, $raw_tokens) = @_;
+
+  my $tokens = convert_string_tokens($raw_tokens);
+  shift @$tokens; # discard plan
+
+  my $first_token = $tokens->[0] or return;
+  $first_token = $first_token->[0] if ref $first_token;
+
+  if ($first_token eq 'skip_all') {
+    if (grep {$_->[0] eq '{' and $_->[2] eq 'BEGIN'} @{$c->{stack} || []}) {
+      $c->{force_cond} = 1;
+    }
+  }
+}
+
 1;
 
 __END__
